@@ -108,8 +108,8 @@ function get_domainname
     # Get ip address
     #ipaddr=$(/sbin/ifconfig | grep 'inet addr:' | grep -v '127.0.0.1' | \
     #    	cut -d: -f2 | awk '{ print $1}')
-    ipaddr=$(lynx -dump whatismyip.org)
-    #ipaddr=$(wget -qO- http://whatismyip.org)
+    #ipaddr=$(w3m -dump whatismyip.org)
+    ipaddr=$(wget -qO- http://whatismyip.org)
     debug "Got IP address '$ipaddr'"
     [[ -z $ipaddr ]] && return
 
